@@ -3,6 +3,7 @@
 
 from __future__ import absolute_import
 
+from builtins import object
 import collections
 import copy
 import logging
@@ -126,7 +127,7 @@ class Attributes(object):
 
     def keys(self):
         '''Return list of attribute names.'''
-        return self._data.keys()
+        return list(self._data.keys())
 
     def __contains__(self, item):
         '''Return whether *item* present.'''
@@ -137,7 +138,7 @@ class Attributes(object):
 
     def __iter__(self):
         '''Return iterator over attributes.'''
-        return self._data.itervalues()
+        return iter(self._data.values())
 
     def __len__(self):
         '''Return count of attributes.'''
@@ -148,7 +149,8 @@ class Attribute(object):
     '''A name and value pair persisted remotely.'''
 
     def __init__(
-        self, name, default_value=ftrack_api.symbol.NOT_SET, mutable=True
+        self, name, default_value=ftrack_api.symbol.NOT_SET, mutable=True,
+        computed=False
     ):
         '''Initialise attribute with *name*.
 
@@ -161,10 +163,14 @@ class Attribute(object):
         are :attr:`ftrack_api.symbol.NOT_SET`. The exception to this is when the
         target value is also :attr:`ftrack_api.symbol.NOT_SET`.
 
+        If *computed* is set to True the value is a remote side computed value
+        and should not be long-term cached.
+
         '''
         super(Attribute, self).__init__()
         self._name = name
         self._mutable = mutable
+        self._computed = computed
         self.default_value = default_value
 
         self._local_key = 'local'
@@ -205,6 +211,11 @@ class Attribute(object):
         '''Return whether attribute is mutable.'''
         return self._mutable
 
+    @property
+    def computed(self):
+        '''Return whether attribute is computed.'''
+        return self._computed
+
     def get_value(self, entity):
         '''Return current value for *entity*.
 
@@ -592,7 +603,7 @@ class KeyValueMappedCollectionAttribute(AbstractCollectionAttribute):
                     del collection_proxy[key]
 
                 # Set new values for existing keys / add new keys.
-                for key, value in value.items():
+                for key, value in list(value.items()):
                     collection_proxy[key] = value
 
                 value = collection_proxy
@@ -679,7 +690,7 @@ class CustomAttributeCollectionAttribute(AbstractCollectionAttribute):
                     del collection_proxy[key]
 
                 # Set new values for existing keys / add new keys.
-                for key, value in value.items():
+                for key, value in list(value.items()):
                     collection_proxy[key] = value
 
                 value = collection_proxy
